@@ -334,7 +334,7 @@ disable_dev() {
 	    min=$(($(stat --printf=0x%T $dev)))
 	    echo "disabling device $dev ($maj:$min)"
             dmsetup remove -f $dev || true
-	    notify_lvmetad $maj:$min
+	    notify_lvmetad --major $maj --minor $min
 	done
 	finish_udev_transaction
 
