@@ -17,12 +17,9 @@
 
 int dumpconfig(struct cmd_context *cmd, int argc, char **argv)
 {
-	const char *file = NULL;
+	const char *file = arg_str_value(cmd, file_ARG, NULL);
 
-	if (arg_count(cmd, file_ARG))
-		file = arg_str_value(cmd, file_ARG, "");
-
-	if (!write_config_file(cmd->cft, file, argc, argv)) {
+	if (!config_write(cmd->cft, file, argc, argv)) {
 		stack;
 		return ECMD_FAILED;
 	}
